@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 module Temple
   module Generators
     # Implements a string buffer.
@@ -9,11 +10,11 @@ module Temple
     #
     # @api public
     class StringBuffer < ArrayBuffer
-      def preamble
-        "#{buffer} = ''"
+      def create_buffer
+        "#{buffer} = ''.dup"
       end
 
-      def postamble
+      def return_buffer
         buffer
       end
 
